diff src/video/SDL_yuv_sw_c.h @ 1895:c121d94672cb

SDL 1.2 is moving to a branch, and SDL 1.3 is becoming the head.
author Sam Lantinga <slouken@libsdl.org>
date Mon, 10 Jul 2006 21:04:37 +0000
parents 51038e80ae59
children 5651642f4a78
line wrap: on
line diff
--- a/src/video/SDL_yuv_sw_c.h	Thu Jul 06 18:01:37 2006 +0000
+++ b/src/video/SDL_yuv_sw_c.h	Mon Jul 10 21:04:37 2006 +0000
@@ -24,14 +24,21 @@
 #include "SDL_video.h"
 #include "SDL_sysvideo.h"
 
 /* This is the software implementation of the YUV video overlay support */
 
-extern SDL_Overlay *SDL_CreateYUV_SW(_THIS, int width, int height, Uint32 format, SDL_Surface *display);
-
-extern int SDL_LockYUV_SW(_THIS, SDL_Overlay *overlay);
+typedef struct SDL_SW_YUVTexture SDL_SW_YUVTexture;
 
-extern void SDL_UnlockYUV_SW(_THIS, SDL_Overlay *overlay);
+SDL_SW_YUVTexture *SDL_SW_CreateYUVTexture(SDL_Texture * texture);
+int SDL_SW_QueryYUVTexturePixels(SDL_SW_YUVTexture * swdata, void **pixels,
+                                 int *pitch);
+int SDL_SW_UpdateYUVTexture(SDL_SW_YUVTexture * swdata, const SDL_Rect * rect,
+                            const void *pixels, int pitch);
+int SDL_SW_LockYUVTexture(SDL_SW_YUVTexture * swdata, const SDL_Rect * rect,
+                          int markDirty, void **pixels, int *pitch);
+void SDL_SW_UnlockYUVTexture(SDL_SW_YUVTexture * swdata);
+int SDL_SW_CopyYUVToRGB(SDL_SW_YUVTexture * swdata, const SDL_Rect * srcrect,
+                        Uint32 target_format, int w, int h, void *pixels,
+                        int pitch);
+void SDL_SW_DestroyYUVTexture(SDL_SW_YUVTexture * swdata);
 
-extern int SDL_DisplayYUV_SW(_THIS, SDL_Overlay *overlay, SDL_Rect *src, SDL_Rect *dst);
-
-extern void SDL_FreeYUV_SW(_THIS, SDL_Overlay *overlay);
+/* vi: set ts=4 sw=4 expandtab: */
@@ -24,14 +24,21 @@
 #include "SDL_sysvideo.h"
 
-/* This is the software implementation of the YUV video overlay support */
+/* This is the software implementation of the YUV texture support */
 